@@ -58,13 +58,13 @@ Stenciller::Plugin::ToHtmlPreBlock - A plugin that transforms to html
 
 =head1 VERSION
 
-Version 0.1200, released 2015-01-17.
+Version 0.1201, released 2015-01-18.
 
 =head1 SYNOPSIS
 
     use Stenciller;
     my $stenciller = Stenciller->new(filepath => 't/corpus/test-1.stencil');
-    my $content = $stenciller->transforme('ToHtmlPreBlock');
+    my $content = $stenciller->transform('ToHtmlPreBlock');
 
 =head1 DESCRIPTION
 
