@@ -1,7 +1,7 @@
 use Stenciller::Standard;
 
 # VERSION
-# ABSTRACT: A plugin that doesn't transforme the text the text
+# ABSTRACT: A plugin that doesn't transform the text
 # PODNAME: Stenciller::Plugin::ToUnparsedText
 
 class Stenciller::Plugin::ToUnparsedText using Moose with Stenciller::Transformer {
@@ -41,17 +41,17 @@ __END__
 
 =head1 NAME
 
-Stenciller::Plugin::ToUnparsedText - A plugin that doesn't transforme the text the text
+Stenciller::Plugin::ToUnparsedText - A plugin that doesn't transform the text
 
 =head1 VERSION
 
-Version 0.1200, released 2015-01-17.
+Version 0.1201, released 2015-01-18.
 
 =head1 SYNOPSIS
 
     use Stenciller;
     my $stenciller = Stenciller->new(filepath => 't/corpus/test-1.stencil');
-    my $content = $stenciller->transforme('ToUnparsedText');
+    my $content = $stenciller->transform('ToUnparsedText');
 
 =head1 DESCRIPTION
 
@@ -68,7 +68,9 @@ This plugin to L<Stenciller> basically returns all text content of the stencils.
 
 <p></p>
 
+<!-- -->
 <table style="margin-bottom: 10px; margin-left: 10px; border-collapse: bollapse;" cellpadding="0" cellspacing="0">
+
 <tr style="vertical-align: top;"><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #eee8e8;">Positional parameters</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #eee8e8;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #eee8e8;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #eee8e8;">&#160;</td><td style="text-align: left; color: #444; padding-left: 5px; font-weight: bold; background-color: #eee8e8;">&#160;</td></tr>
 <tr style="vertical-align: top;">
 <td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"><code>$transform_args</code>
@@ -77,7 +79,7 @@ This plugin to L<Stenciller> basically returns all text content of the stencils.
 <td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;"><a href="https://metacpan.org/pod/Types::Standard#HashRef">HashRef</a>
 
 </td>
-<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;">optional, default <code>= HASH(0x99ba070)</code>
+<td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  padding: 3px 6px; border-bottom: 1px solid #eee;">optional, default <code>= { }</code>
 
 </td>
 <td style="vertical-align: top; border-right: 1px solid #eee; white-space: nowrap;  border-bottom: 1px solid #eee;"></td>
@@ -94,18 +96,20 @@ This plugin to L<Stenciller> basically returns all text content of the stencils.
 
 =end HTML
 
-The currently available keys in the C<$transform_args> is:
+The currently available keys in the C<$transform_args> hash ref is:
 
-B<C<skip_header_lines => 1>>
+B<C<skip_header_lines =E<gt> 1>>
 
 C<skip_header_lines> takes a boolean indicating if the L<Stenciller's|Stenciller> header_lines should be skipped. Default is C<0>.
 
-B<C<stencils => []>>
+B<C<stencils =E<gt> [ ]>>
 
 C<stencils> takes an array reference of which stencils in the currently parsed file that should be included in the output. The index is zero based.
 
 If this plugin is used via L<Pod::Elemental::Transformer::Stenciller> it could be used like this in pod:
 
+    =pod
+
     # includes header_lines and all stencils
     :stenciller ToUnparsedText atestfile-1.stencil
 
