@@ -1,4 +1,6 @@
 use 5.14.0;
+use strict;
+use warnings;
 
 package Stenciller::Standard {
 
@@ -45,7 +47,7 @@ Stenciller::Standard - Import to all
 
 =head1 VERSION
 
-Version 0.1200, released 2015-01-17.
+Version 0.1201, released 2015-01-18.
 
 =head1 SOURCE
 
